local awful = require("awful")
local gears = require("gears")
local wibox = require("wibox")
local theme = require("theme")
local naughty = require("naughty")

local tag_list = {}

tag_list.create = function(s)
    local filter = function(tag)
        count = 0
        for idx, tag in ipairs(s.tags) do
            if #tag:clients() > 0 or tag.selected then
                count = count + 1
            end
        end
        return (#tag:clients() > 0 and count > 1) or (tag.selected and #tag:clients() == 0)
    end

    local taglist_buttons = awful.util.table.join(
        awful.button({}, 1,
        function(c)
            c.selected = true
            for idx, tag in ipairs(s.tags) do
                if tag.index ~= c.index then
                    tag.selected = false
                end
            end
        end
        )
    )
    return awful.widget.taglist {
        screen  = s,
        -- filter  = awful.widget.taglist.filter.noempty,
        filter  = filter,
        widget_template = {
            {
                {
                    id     = 'index_role',
                    widget = wibox.widget.textbox,
                },
                left  = 10,
                right = 10,
                widget = wibox.container.margin
            },
            id     = 'background_role',
            widget = wibox.container.background,

            create_callback = function(self, c3, index, objects)
                self:get_children_by_id('index_role')[1].markup = '<b> '..c3.name..' </b>'
                self:connect_signal('mouse::enter', function()
                    if self.bg ~= theme.top_panel_powerline then
                        self.backup     = self.bg
                        self.has_backup = true
                    end
                    self.bg = theme.top_panel_powerline
                end)
                self:connect_signal('mouse::leave', function()
                    if self.has_backup and not c3.selected then self.bg = self.backup end
                end)
            end,
        },
        buttons = taglist_buttons,
    }

end
return tag_list
